@@ -433,8 +433,8 @@ string_print_timestamp(String *s)
 }
 
 /* Convert time fields. Returns a signed (at least) 64-bit UNIX timestamp.
-   Parameters should be passed as they are in a struct tm:
-   that is: year = year - 1900, month = month - 1. */
+ * Parameters should be passed as they are in a struct tm:
+ * that is: year = year - 1900, month = month - 1. */
 static long long
 datetounix(long long year, int mon, int day, int hour, int min, int sec)
 {
@@ -459,8 +459,8 @@ datetounix(long long year, int mon, int day, int hour, int min, int sec)
 		t = 31536000 * (year - 70) + (86400 * leaps); /* 365 * 86400 = 31536000 */
 	} else {
 		/* general leap year calculation:
-		   leap years occur mostly every 4 years but every 100 years
-		   a leap year is skipped unless the year is divisible by 400 */
+		 * leap years occur mostly every 4 years but every 100 years
+		 * a leap year is skipped unless the year is divisible by 400 */
 		cycles = (year - 100) / 400;
 		rem = (year - 100) % 400;
 		if (rem < 0) {
@@ -489,7 +489,7 @@ datetounix(long long year, int mon, int day, int hour, int min, int sec)
 		leaps += (97 * cycles) + (24 * centuries) - is_leap;
 
 		/* adjust 8 leap days from 1970 up to and including 2000:
-		   ((30 * 365) + 8) * 86400 = 946771200 */
+		 * ((30 * 365) + 8) * 86400 = 946771200 */
 		t = ((year - 100) * 31536000LL) + (leaps * 86400LL) + 946771200LL;
 	}
 	t += secs_through_month[mon];
@@ -555,7 +555,7 @@ gettzoffset(const char *s)
 }
 
 /* Parse time string `s` into the UNIX timestamp `tp`.
-   Returns 0 on success or -1 on failure. */
+ * Returns 0 on success or -1 on failure. */
 static int
 parsetime(const char *s, long long *tp)
 {
@@ -645,14 +645,14 @@ parsetime(const char *s, long long *tp)
 		}
 		va[vi] = v;
 
-		if ((vi < 2 && *s == '-') ||
-		    (vi == 2 && (*s == 'T' || ISSPACE((unsigned char)*s))) ||
+		if ((vi < 2 && (*s == '-' || *s == '/')) ||
+		    (vi == 2 && (*s == 'T' || *s == 't' || ISSPACE((unsigned char)*s))) ||
 		    (vi > 2 && *s == ':'))
 			s++;
 	}
 
 	/* skip milliseconds in for example: "%Y-%m-%dT%H:%M:%S.000Z" */
-	if (*s == '.') {
+	if (*s == '.' || *s == ',') {
 		for (s++; ISDIGIT((unsigned char)*s); s++)
 			;
 	}
@@ -725,7 +725,7 @@ xmlattr(XMLParser *p, const char *t, size_t tl, const char *n, size_t nl,
 		return;
 
 	/* content-type may be for Atom: text, xhtml, html or a mime-type.
-	   for MRSS (media:description): plain, html. */
+	 * for MRSS (media:description): plain, html. */
 	if (ISCONTENTTAG(ctx)) {
 		if (isattr(n, nl, STRP("type")))
 			string_append(&attrtype, v, vl);
@@ -921,7 +921,7 @@ xmltagstartparsed(XMLParser *p, const char *t, size_t tl, int isshort)
 			ctx.tag.id = RSSTagGuidPermalinkFalse;
 	} else if (ctx.tag.id == AtomTagLink) {
 		/* empty or "alternate": other types could be
-		   "enclosure", "related", "self" or "via" */
+		 * "enclosure", "related", "self" or "via" */
 		if (!attrrel.len || isattr(attrrel.data, attrrel.len, STRP("alternate")))
 			ctx.tag.id = AtomTagLinkAlternate;
 		else if (isattr(attrrel.data, attrrel.len, STRP("enclosure")))
@@ -933,7 +933,7 @@ xmltagstartparsed(XMLParser *p, const char *t, size_t tl, int isshort)
 	tagid = ctx.tag.id;
 
 	/* map tag type to field: unknown or lesser priority is ignored,
-	   when tags of the same type are repeated only the first is used. */
+	 * when tags of the same type are repeated only the first is used. */
 	if (fieldmap[tagid] == -1 ||
 	    (!ISFEEDFIELDMULTI(fieldmap[tagid]) &&
 	     tagid <= ctx.fields[fieldmap[tagid]].tagid)) {
@@ -967,7 +967,7 @@ xmltagstartparsed(XMLParser *p, const char *t, size_t tl, int isshort)
 	ctx.fields[fieldmap[tagid]].tagid = tagid;
 
 	/* clear field if it is overwritten (with a priority order) for the new
-	   value, if the field can have multiple values then do not clear it. */
+	 * value, if the field can have multiple values then do not clear it. */
 	if (!ISFEEDFIELDMULTI(fieldmap[ctx.tag.id]))
 		string_clear(ctx.field);
 }
@@ -991,9 +991,9 @@ xmltagend(XMLParser *p, const char *t, size_t tl, int isshort)
 			return;
 		}
 	} else if (ctx.tag.id && istag(ctx.tag.name, ctx.tag.len, t, tl)) {
-		/* matched tag end: close it */
-		/* copy also to the link field if the attribute isPermaLink="true"
-		   and it is not set by a tag with higher priority. */
+		/* matched tag end: close it.
+		 * copy also to the link field if the attribute isPermaLink="true"
+		 * and it is not set by a tag with higher priority. */
 		if (ctx.tag.id == RSSTagGuidPermalinkTrue && ctx.field &&
 		    ctx.tag.id > ctx.fields[FeedFieldLink].tagid) {
 			string_clear(&ctx.fields[FeedFieldLink].str);
@@ -1022,8 +1022,8 @@ xmltagend(XMLParser *p, const char *t, size_t tl, int isshort)
 	}
 
 	/* temporary string: for fields that cannot be processed
-	   directly and need more context, for example by its tag
-	   attributes, like the Atom link rel="alternate|enclosure". */
+	 * directly and need more context, for example by its tag
+	 * attributes, like the Atom link rel="alternate|enclosure". */
 	if (tmpstr.len && ctx.field) {
 		if (ISFEEDFIELDMULTI(fieldmap[ctx.tag.id])) {
 			if (ctx.field->len)
